Calculate p-values for two sided case.

exactt.pval.new.reg(
  Y.temp,
  X1.temp,
  X2.temp,
  indep.X2.index,
  permIndices,
  GX.indices,
  Q.X1.temp,
  studentize,
  side,
  denominator,
  root.tolerance
)

Arguments

Y.temp

The response vector for which the test is being performed.

X1.temp

A numeric column vector of the primary variable.

X2.temp

A numeric matrix of the secondary variables.

indep.X2.index

The indices of variables in X2 that are independent to X1.

permIndices

A matrix of permutation indices used in the test.

GX.indices

A matrix of permutation indices to create GX matrices.

Q.X1.temp

A numeric column vector of the primary variable annihilated by GX2.

studentize

A boolean indicating whether to studentize the randomization statistics

side

A character to indicate the side of the test.

denominator

Character argument indicating how to calculate epsilon hat.

root.tolerance

Tolerance for determining real and extraneous roots (when denominator = "X1" or "noX1").