Calculate p-values for two sided case.
exactt.pval.new.reg(
Y.temp,
X1.temp,
X2.temp,
indep.X2.index,
permIndices,
GX.indices,
Q.X1.temp,
studentize,
side,
denominator,
root.tolerance
)The response vector for which the test is being performed.
A numeric column vector of the primary variable.
A numeric matrix of the secondary variables.
The indices of variables in X2 that are independent to X1.
A matrix of permutation indices used in the test.
A matrix of permutation indices to create GX matrices.
A numeric column vector of the primary variable annihilated by GX2.
A boolean indicating whether to studentize the randomization statistics
A character to indicate the side of the test.
Character argument indicating how to calculate epsilon hat.
Tolerance for determining real and extraneous roots (when denominator = "X1" or "noX1").